Dynamic Loaded Column Chart

<div id="wrap"> <select id="model" class="flat-select" @change="changeData"> <option value="iphone5">iPhone 5</option> <option value="iphone6">iPhone 6</option> <option value="iphone7">iPhone 7</option> </select> <div id="chart-year"> <apexchart type="bar" height="400" ref="chart" :options="chartOptions" :series="series"></apexchart> </div> <div id="chart-quarter"> <apexchart type="bar" height="400" ref="chartQuarter" :options="chartOptionsQuarter" :series="seriesQuarter"></apexchart> </div> </div>